@@ -4,13 +4,16 @@ pub mod arg_str_serialize;
 pub mod auto_impl;
 pub mod auto_impl_event;
 pub mod auto_impl_module;
+pub mod auto_impl_proxy;
 pub mod auto_impl_storage;
-pub mod callable_gen;
 pub mod callback_gen;
+pub mod callback_proxies_gen;
 pub mod contract_gen;
 pub mod function_selector;
 pub mod method_call_gen;
 pub mod method_gen;
 pub mod payable_gen;
+pub mod proxy_gen;
 pub mod snippets;
+pub mod supertrait_gen;
 pub mod util;
